// Copyright (c) FIRST and other WPILib contributors.
// Open Source Software; you can modify and/or share it under the terms of
// the WPILib BSD license file in the root directory of this project.

package frc.robot;

import edu.wpi.first.wpilibj.shuffleboard.BuiltInWidgets;
import edu.wpi.first.wpilibj.shuffleboard.Shuffleboard;
import edu.wpi.first.wpilibj.shuffleboard.ShuffleboardTab;
import edu.wpi.first.wpilibj2.command.Command;
import edu.wpi.first.wpilibj2.command.button.CommandXboxController;
import frc.robot.constants.OIConstants;
import frc.robot.subsystems.Drivetrain;
import frc.robot.subsystems.Flicker;
import frc.robot.subsystems.Shooter;


public class RobotContainer {
  private Flicker flicker;
  private Shooter shooter;
  private Drivetrain drivetrain;
  private CommandXboxController driver;
  public RobotContainer() {
    drivetrain = new Drivetrain();
    flicker = new Flicker();
    driver = new CommandXboxController(OIConstants.kDriverUSB); //sets up controlers

    configureBindings();
    configureShuffleboard();
  }

  private void configureBindings() {
    drivetrain.setDefaultCommand(
      drivetrain.driveArcade(
        driver::getLeftY, 
        driver::getLeftX //manual controls for driveing
      )
    );  
    flicker.setDefaultCommand(flicker.stop());
    driver.a().onTrue(flicker.setSpeed(() ->1));

    shooter.setDefaultCommand(shooter.stop());
    driver.rightBumper().onTrue(shooter.setSpeed(()->1)); //manual controls for shooter and flicker
    

  }
  private void configureShuffleboard() {
    ShuffleboardTab robotIndicatorTab = Shuffleboard.getTab(OIConstants.kRobotIndicatorsTabName);

    robotIndicatorTab.addBoolean("Sensors", flicker::photoswich)
    .withPosition(0, 0).
    withSize(2, 1).
    withWidget(BuiltInWidgets.kBooleanBox); //sets up the wiget

    
  }
    

  public Command getAutonomousCommand() {
    return drivetrain.driveTank(() -> .5,() -> .5).withTimeout(2). andThen(
      shooter.setSpeed(()-> 1)).withTimeout(1).andThen(
        shooter.setSpeed(()->1)).alongWith(
          flicker.setSpeed(()->1)); //sets up the anumus command, it drives forward for 2 seconds, spins the shooter mototrs for 1 second, and both shooter and flicker for 3 seconds.
  }
}
